@@ -9,9 +9,9 @@ import jinja2.exceptions
 import pkg_resources
 import requests
 import unidecode
-from flask import make_response, render_template, request
+from flask import Response, make_response, render_template, request
 
-from . import card_list, config
+from . import card_list, config, moxfield_decklist
 from .navigation import HELPER
 
 version = pkg_resources.Environment()["barrins-codex"][0].version
@@ -32,6 +32,11 @@ else:
     CARDS = card_list.build()
 
 BASE_CONTEXT = {
+    "W": "⚪",
+    "U": "🔵",
+    "B": "⚫",
+    "R": "🔴",
+    "G": "🟢",
     "version": version,
     "pilotes_habitue": [
         page for page in HELPER if HELPER.get(page, {}).get("cat") == "habitue"
@@ -152,6 +157,24 @@ def static_fonts(font=None):
     return flask.redirect(flask.url_for("static", filename=f"fonts/{font}"))
 
 
+# Serve decklist routes
+@app.route("/decklist/")
+@app.route("/decklist/<moxfield_key>")
+def download_list(moxfield_key=None):
+    if not moxfield_key:
+        return False
+
+    response = moxfield_decklist.export(moxfield_key)
+
+    return Response(
+        response["list"],
+        mimetype="text/plain",
+        headers={
+            "Content-Disposition": f"attachment;filename=\"{response['name']}.txt\""
+        },
+    )
+
+
 # Default route
 @app.route("/")
 @app.route("/<path:page>")
@@ -242,13 +265,13 @@ def linker():
         return "Barrin's Codex"
 
     def page_name():
+        name = "Barrin's Codex"
         try:
             if HELPER.get(path, {}).get("self").path != "":
                 name = HELPER.get(path, {}).get("self").name
-                return f"{name}"
         except AttributeError:
             pass
-        return "Barrin's Codex"
+        return f"{name}"
 
     return dict(
         url=_url,
@@ -285,19 +308,6 @@ def display_card():
                 query = query + "&face=back"
         return "https://api.scryfall.com/cards/" + f"{card['id']}?{query}"
 
-    def card_link(name):
-        return flask.Markup(
-            """
-<img src="https://api.scryfall.com/cards/{scryfallId}?{query}"
-    alt="{name}" class="col-md-3 float-md-end mx-md-1" max-width="100%"
-    loading="lazy" />""".format(
-                # replace spaces with non-breakable spaces in card names
-                name=CARDS[_name(name)]["name"].replace(" ", " "),
-                query="format=image&version=border_crop",
-                scryfallId=CARDS[_name(name)]["id"],
-            )
-        )
-
     def img_card(name, front=True):
         if _name(name) not in CARDS.keys():
             fuzzy = re.sub(r"[^\w\s]", "", name)
@@ -313,12 +323,41 @@ def display_card():
                 query = query + "&face=back"
         return f"https://api.scryfall.com/cards/{card['id']}?{query}"
 
+    def card_link(name, phrase=None):
+        return flask.Markup(
+            """
+<img src="https://api.scryfall.com/cards/{scryfallId}?{query}"
+    alt="{name}" class="col-md-3 float-md-end mx-md-1" max-width="100%"
+    loading="lazy" />""".format(
+                # replace spaces with non-breakable spaces in card names
+                name=phrase or CARDS[_name(name)]["name"].replace(" ", " "),
+                query="format=image&version=border_crop",
+                scryfallId=CARDS[_name(name)]["id"],
+            )
+        )
+
+    def card_hover(name, phrase=None):
+        return flask.Markup(
+            """<span class="card-name" scryfallId="{scryfallId}" data-tippy-content="
+<div class='card-container'>
+<img
+    data-src='https://api.scryfall.com/cards/{scryfallId}?{query}'
+    class='card-image'
+/>
+</div>">{name}</span>""".format(
+                # replace spaces with non-breakable spaces in card names
+                name=phrase or CARDS[_name(name)]["name"].replace(" ", " "),
+                query="format=image&version=border_crop",
+                scryfallId=CARDS[_name(name)]["id"],
+            )
+        )
+
     return dict(
         deck_name=card_name_from_page,
         img_crop=img_crop,
         img_card=img_card,
         card_link=card_link,
-        card_hover=card_link,
+        card_hover=card_hover,
     )
 
 
@@ -364,3 +403,24 @@ def players():
         return "Barrin's Codex"
 
     return dict(player_name=player_name, player_nickname=player_nickname)
+
+
+@app.context_processor
+def decklist_processor():
+    def decklist(url, name=None, outline=False):
+        return flask.Markup(
+            """
+<div class="col-12 d-flex flew-row mt-4 me-1">
+    <a class="btn {btn}-secondary decklist col-10" role="button" target="_blank"
+        href="{url}">{name}</a>
+    <a class="btn {btn}-warning col-2 ms-1" role="button"
+        href="{key}"><i class="fa-solid fa-file-lines"></i></a>
+</div>""".format(
+                name=name or "Decklist",
+                url=url,
+                key="/decklist/" + url[31:],
+                btn="btn-outline" if outline else "btn",
+            )
+        )
+
+    return dict(decklist=decklist)
